@@ -309,9 +309,11 @@ show_popup_window (BonoboUIToolbar *toolbar)
 	BonoboUIToolbarPrivate *priv;
 	const GtkAllocation *toolbar_allocation;
 	gint x, y;
+#ifdef HAVE_GTK_MULTIHEAD
 	GdkScreen *screen;
 	gint screen_width, screen_height;
 	gint window_width, window_height;
+#endif
 
 	priv = toolbar->priv;
 
@@ -326,6 +328,7 @@ show_popup_window (BonoboUIToolbar *toolbar)
 	else
 		y += toolbar_allocation->y + toolbar_allocation->height;
 
+#ifdef HAVE_GTK_MULTIHEAD
 	gtk_window_get_size (GTK_WINDOW (priv->popup_window),
 			     &window_width, &window_height);
 	screen = gtk_widget_get_screen (GTK_WIDGET (toolbar));
@@ -335,6 +338,7 @@ show_popup_window (BonoboUIToolbar *toolbar)
 		x -= window_width;
 	if ((y + window_height) > screen_height)
 		x += toolbar_allocation->width;
+#endif
 
 	gtk_window_move (GTK_WINDOW (priv->popup_window), x, y);
 
@@ -1015,7 +1019,10 @@ impl_get_property (GObject    *object,
 {
 	BonoboUIToolbar *toolbar = BONOBO_UI_TOOLBAR (object);
 	BonoboUIToolbarPrivate *priv = toolbar->priv;
+	gint border_width;
 
+	border_width = GTK_CONTAINER (object)->border_width;
+	
 	switch (property_id) {
 	case PROP_ORIENTATION:
 		g_value_set_uint (
@@ -1028,17 +1035,17 @@ impl_get_property (GObject    *object,
 		update_sizes (toolbar);
 		if (bonobo_ui_toolbar_get_orientation (toolbar) ==
 		    GTK_ORIENTATION_HORIZONTAL)
-			g_value_set_uint (value, priv->total_width);
+			g_value_set_uint (value, priv->total_width + 2 * border_width);
 		else
-			g_value_set_uint (value, priv->max_width);
+			g_value_set_uint (value, priv->max_width + 2 * border_width);
 		break;
 	case PROP_PREFERRED_HEIGHT:
 		update_sizes (toolbar);
 		if (bonobo_ui_toolbar_get_orientation (toolbar) ==
 		    GTK_ORIENTATION_HORIZONTAL)
-			g_value_set_uint (value, priv->max_height);
+			g_value_set_uint (value, priv->max_height + 2 * border_width);
 		else
-			g_value_set_uint (value, priv->total_height);
+			g_value_set_uint (value, priv->total_height + 2 * border_width);
 		break;
 	default:
 		break;
